
    import * as React from 'react';

    import { IconType } from '../types';

    type SiAccentureProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#A100FF';

    const SiAccenture: IconType = React.forwardRef<SVGSVGElement, SiAccentureProps>(function SiAccenture({title = 'Accenture', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='m.66 16.95 13.242-4.926L.66 6.852V0l22.68 9.132v5.682L.66 24Z' />
        </svg>
      );
    });

    export { SiAccenture as default, defaultColor };
  