
    import * as React from 'react';

    import { IconType } from '../types';

    type SiCnesProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#204F8C';

    const SiCnes: IconType = React.forwardRef<SVGSVGElement, SiCnesProps>(function SiCnes({title = 'CNES', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M10.173 0h.9531V13.7978c0 2.8809 3.6823 8.7293 9.7256 4.8304l.1227-.0684C19.6214 21.7444 16.2555 24 12.3174 24 7.1854 24 3.025 20.1694 3.025 15.444c0-4.0457 3.0498-7.4356 7.148-8.327V0Zm10.3989 11.5108c-1.5249-2.7076-4.5751-4.5697-8.1029-4.6216-.0643 1.1076.8245 7.1347 4.9603 7.4718 1.0779.0879 3.84-.5495 3.1426-2.8502Z' />
        </svg>
      );
    });

    export { SiCnes as default, defaultColor };
  