
    import * as React from 'react';

    import { IconType } from '../types';

    type SiFramerProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#0055FF';

    const SiFramer: IconType = React.forwardRef<SVGSVGElement, SiFramerProps>(function SiFramer({title = 'Framer', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M4 0h16v8h-8zM4 8h8l8 8H4zM4 16h8v8z' />
        </svg>
      );
    });

    export { SiFramer as default, defaultColor };
  