
    import * as React from 'react';

    import { IconType } from '../types';

    type SiIstioProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#466BB0';

    const SiIstio: IconType = React.forwardRef<SVGSVGElement, SiIstioProps>(function SiIstio({title = 'Istio', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M4 21 20 21 10 24zM4 20 10 19 10 8zM11 19 20 20 11 0z' />
        </svg>
      );
    });

    export { SiIstio as default, defaultColor };
  