
    import * as React from 'react';

    import { IconType } from '../types';

    type SiKedroProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#FFC900';

    const SiKedro: IconType = React.forwardRef<SVGSVGElement, SiKedroProps>(function SiKedro({title = 'Kedro', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='m12 0 12 12-12 12L0 12 12 0z' />
        </svg>
      );
    });

    export { SiKedro as default, defaultColor };
  