
    import * as React from 'react';

    import { IconType } from '../types';

    type SiKtorProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#087CFA';

    const SiKtor: IconType = React.forwardRef<SVGSVGElement, SiKtorProps>(function SiKtor({title = 'Ktor', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M8 0 0 8l8 8V8h8zm8 8v8H8l8 8 8-8z' />
        </svg>
      );
    });

    export { SiKtor as default, defaultColor };
  