
    import * as React from 'react';

    import { IconType } from '../types';

    type SiLinuxfoundationProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#003778';

    const SiLinuxfoundation: IconType = React.forwardRef<SVGSVGElement, SiLinuxfoundationProps>(function SiLinuxfoundation({title = 'Linux Foundation', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M4.8 19.2h9.6V24H0V9.6h4.8v9.6zM0 0v7.2h4.8V4.822h14.4V19.2h-2.4V24H24V0H0z' />
        </svg>
      );
    });

    export { SiLinuxfoundation as default, defaultColor };
  