
    import * as React from 'react';

    import { IconType } from '../types';

    type SiLospecProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#EAEAEA';

    const SiLospec: IconType = React.forwardRef<SVGSVGElement, SiLospecProps>(function SiLospec({title = 'Lospec', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M4.23 0v24h15.541v-8.4004h-7.1719v3.5996H11.402V0z' />
        </svg>
      );
    });

    export { SiLospec as default, defaultColor };
  