
    import * as React from 'react';

    import { IconType } from '../types';

    type SiLucidProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#282C33';

    const SiLucid: IconType = React.forwardRef<SVGSVGElement, SiLucidProps>(function SiLucid({title = 'Lucid', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M12 0 3.694 4.8V24L12 19.2Zm0 19.2v4.502h8.305V14.4Z' />
        </svg>
      );
    });

    export { SiLucid as default, defaultColor };
  