
    import * as React from 'react';

    import { IconType } from '../types';

    type SiNetappProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#0067C5';

    const SiNetapp: IconType = React.forwardRef<SVGSVGElement, SiNetappProps>(function SiNetapp({title = 'NetApp', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M0 2v20h9.33V10h5.34v12H24V2Z' />
        </svg>
      );
    });

    export { SiNetapp as default, defaultColor };
  