
    import * as React from 'react';

    import { IconType } from '../types';

    type SiNexonProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#000000';

    const SiNexon: IconType = React.forwardRef<SVGSVGElement, SiNexonProps>(function SiNexon({title = 'NEXON', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M10.714 15.358V0L0 5.697v15.358L13.29 24 24 18.303zm-9.495-1.219 7.291 1.568-7.291 3.832zm11.895 8.578L2.35 20.327l7.454-3.926 10.846 2.406z' />
        </svg>
      );
    });

    export { SiNexon as default, defaultColor };
  