
    import * as React from 'react';

    import { IconType } from '../types';

    type SiNicehashProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#FBC342';

    const SiNicehash: IconType = React.forwardRef<SVGSVGElement, SiNicehashProps>(function SiNicehash({title = 'NiceHash', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M12 24c6.627 0 12-5.373 12-12h-8a4 4 0 0 1-8 0H0c0 6.627 5.373 12 12 12zM8 4a4 4 0 0 1-4 4 4 4 0 0 1-4-4 4 4 0 0 1 4-4 4 4 0 0 1 4 4Zm4-4h12v8H12Z' />
        </svg>
      );
    });

    export { SiNicehash as default, defaultColor };
  