
    import * as React from 'react';

    import { IconType } from '../types';

    type SiOpen3dProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#000000';

    const SiOpen3d: IconType = React.forwardRef<SVGSVGElement, SiOpen3dProps>(function SiOpen3d({title = 'Open3D', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M5.998 1.606 0 12l5.998 10.394h2.094l1.954-3.383H7.952L4.06 12.268h8.149l3.56 6.157L19.483 12l-3.715-6.444-3.56 6.18H4.055l3.893-6.747h2.098L8.088 1.606Zm2.71 0 1.954 3.383h5.386L20.096 12l-4.044 7.011h-5.394l-1.954 3.383h9.294l.488-.847L24 12 18.002 1.606Z' />
        </svg>
      );
    });

    export { SiOpen3d as default, defaultColor };
  