
    import * as React from 'react';

    import { IconType } from '../types';

    type SiOrangeProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#FF7900';

    const SiOrange: IconType = React.forwardRef<SVGSVGElement, SiOrangeProps>(function SiOrange({title = 'Orange', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M0 0h24v24H0V0Zm3.43 20.572h17.143v-3.429H3.43v3.429Z' />
        </svg>
      );
    });

    export { SiOrange as default, defaultColor };
  