
    import * as React from 'react';

    import { IconType } from '../types';

    type SiPeertubeProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#F1680D';

    const SiPeertube: IconType = React.forwardRef<SVGSVGElement, SiPeertubeProps>(function SiPeertube({title = 'PeerTube', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M12 6.545v10.91L20.727 12M3.273 12v12L12 17.455M3.273 0v12L12 6.545' />
        </svg>
      );
    });

    export { SiPeertube as default, defaultColor };
  