
    import * as React from 'react';

    import { IconType } from '../types';

    type SiRadarProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#007AFF';

    const SiRadar: IconType = React.forwardRef<SVGSVGElement, SiRadarProps>(function SiRadar({title = 'Radar', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M12 0L2.197 23.975 12 19.952 21.803 24z' />
        </svg>
      );
    });

    export { SiRadar as default, defaultColor };
  