
    import * as React from 'react';

    import { IconType } from '../types';

    type SiSocketProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#C93CD7';

    const SiSocket: IconType = React.forwardRef<SVGSVGElement, SiSocketProps>(function SiSocket({title = 'Socket', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M2.93 11.171c0 5.92 3.778 10.957 9.063 12.829a13.652 13.652 0 0 0 6.513-4.89 13.497 13.497 0 0 0 2.564-7.939V3.274L11.997 0 2.933 3.274v7.897zm7.491-6.09h4.208L13.34 9.47h2.292l-6.264 9.446 1.486-6.858H8.365z' />
        </svg>
      );
    });

    export { SiSocket as default, defaultColor };
  