
    import * as React from 'react';

    import { IconType } from '../types';

    type SiVerizonProps = React.ComponentPropsWithoutRef<'svg'> & {
      /**
       * The title provides an accessible short text description to the SVG
       */
      title?: string;
      /**
       * Hex color or color name or "default" to use the default hex for each icon
       */
      color?: string;
      /**
       * The size of the Icon.
       */
      size?: string | number;
    }

    const defaultColor = '#CD040B';

    const SiVerizon: IconType = React.forwardRef<SVGSVGElement, SiVerizonProps>(function SiVerizon({title = 'Verizon', color = 'currentColor', size = 24, ...others }, ref) {
      if (color === 'default') {
        color = defaultColor;
      }

      return (
        <svg
          xmlns='http://www.w3.org/2000/svg'
          width={size}
          height={size}
          fill={color}
          viewBox='0 0 24 24'
          ref={ref}
          {...others}
        >
          <title>{title}</title>
          <path d='M18.302 0H22v.003L10.674 24H7.662L2 12h3.727l3.449 7.337z' />
        </svg>
      );
    });

    export { SiVerizon as default, defaultColor };
  